diff --git a/Modules/FindHDF5.cmake b/Modules/FindHDF5.cmake
index ff198665d6aa2742e9cb8beede3286a79662c847..1e2ea69a757163a27edfa73f0b8ee8f009ddef96 100644
--- a/Modules/FindHDF5.cmake
+++ b/Modules/FindHDF5.cmake
@@ -96,9 +96,14 @@
 #
 # The following variable can be set to guide the search for HDF5 libraries and includes:
 #
-# HDF5_ROOT
+# ``HDF5_ROOT``
+#   Specify the path to the HDF5 installation to use.
 #
 # Set HDF5_FIND_DEBUG to true to get some extra debugging output.
 
 # This module is maintained by Will Dicharry <wdicharry@stellarscience.com>.
 
@@ -399,7 +404,7 @@ else()
 endif()
 
 # Try to find HDF5 using an installed hdf5-config.cmake
-if(NOT HDF5_FOUND)
+if(NOT HDF5_FOUND AND NOT HDF5_NO_FIND_PACKAGE_CONFIG_FILE)
     find_package(HDF5 QUIET NO_MODULE
       HINTS ${HDF5_ROOT}
       ${_HDF5_SEARCH_OPTS}
@@ -96,9 +96,14 @@
 #
-# Set HDF5_FIND_DEBUG to true to get some extra debugging output.
+# ``HDF5_FIND_DEBUG``
+#   Set to a true value to get some extra debugging output.
+#
+# ``HDF5_NO_FIND_PACKAGE_CONFIG_FILE``
+#   Set to a true value to skip trying to find ``hdf5-config.cmake``.
 
 # This module is maintained by Will Dicharry <wdicharry@stellarscience.com>.